@@ -40,6 +40,7 @@
 #include <QtCore/QDebug>
 #include <QtCore/QString>
 #include <QtCore/QLatin1String>
+#include <QtCore/QFile>
 
 
 using namespace Soprano;
@@ -58,6 +59,17 @@ static lucene::search::Query* createSingleFieldQuery( const string& field,
                                                       const Strigi::Query& query );
 static lucene::search::Query* createMultiFieldQuery( const Strigi::Query& query );
 
+#if 0
+static QString luceneQueryEscape( const QString& s )
+{
+    /* Chars to escape: + - && || ! ( ) { } [ ] ^ " ~  : \ */
+
+    static QRegExp rx( "([\\-" + QRegExp::escape( "+&|!(){}[]^\"~:\\" ) + "])" );
+    QString es( s );
+    es.replace( rx, "\\\\1" );
+    return es;
+}
+#endif
 
 static lucene::index::Term* createWildCardTerm( const TString& name,
                                                 const string& value )
@@ -266,7 +278,7 @@ int32_t Strigi::Soprano::IndexReader::countHits( const Query& query )
 
     lucene::search::Query* q = createQuery( query );
     ::Soprano::QueryResultIterator hits = d->repository->executeQuery( TString( q->toString(), true ),
-                                                                       ::Soprano::Query::QUERY_LANGUAGE_USER,
+                                                                       ::Soprano::Query::QueryLanguageUser,
                                                                        QLatin1String( "lucene" ) );
 //    Iterator< ::Soprano::Index::QueryHit> hits = d->repository->index()->search( q );
     int s = 0;
@@ -288,7 +300,7 @@ void Strigi::Soprano::IndexReader::getHits( const Strigi::Query& query,
     qDebug() << "IndexReader::getHits in thread" << QThread::currentThread();
     lucene::search::Query* bq = createQuery( query );
     ::Soprano::QueryResultIterator hits = d->repository->executeQuery( TString( bq->toString(), true ),
-                                                                       ::Soprano::Query::QUERY_LANGUAGE_USER,
+                                                                       ::Soprano::Query::QueryLanguageUser,
                                                                        QLatin1String( "lucene" ) );
 //    Iterator< ::Soprano::Index::QueryHit> hits = d->repository->index()->search( bq );
 
@@ -339,7 +351,7 @@ std::vector<Strigi::IndexedDocument> Strigi::Soprano::IndexReader::query( const
     vector<IndexedDocument> results;
     lucene::search::Query* bq = createQuery( query );
     ::Soprano::QueryResultIterator hits = d->repository->executeQuery( TString( bq->toString(), true ),
-                                                                       ::Soprano::Query::QUERY_LANGUAGE_USER,
+                                                                       ::Soprano::Query::QueryLanguageUser,
                                                                        QLatin1String( "lucene" ) );
 //    Iterator< ::Soprano::Index::QueryHit> hits = d->repository->index()->search( bq );
 
@@ -373,28 +385,40 @@ void Strigi::Soprano::IndexReader::getChildren( const std::string& parent,
                                                 std::map<std::string, time_t>& children )
 {
 //    qDebug() << "IndexReader::getChildren in thread" << QThread::currentThread();
-    QString query = QString( "select distinct ?path ?mtime where { ?r <%1> \"%2\"^^<%3> . ?r <%4> ?mtime . ?r <%5> ?path . }")
-                    .arg( Util::fieldUri( FieldRegister::parentLocationFieldName ).toString() )
-                    .arg( escapeLiteralForSparqlQuery( QString::fromUtf8( parent.c_str() ) ) )
-                    .arg( Vocabulary::XMLSchema::string().toString() )
-                    .arg( Util::fieldUri( FieldRegister::mtimeFieldName ).toString() )
-                    .arg( Util::fieldUri( FieldRegister::pathFieldName ).toString() );
+    QString query = QString( "select distinct ?path ?mtime where { "
+                             "{ { ?r <%1> \"%2\"^^<%3> . } UNION { ?r <%1> %6 . } } . "
+                             "?r <%4> ?mtime . "
+                             "?r <%5> ?path . "
+                             "}")
+                    .arg( Util::fieldUri( FieldRegister::parentLocationFieldName ).toString(),
+                          escapeLiteralForSparqlQuery( QString::fromUtf8( parent.c_str() ) ),
+                          Vocabulary::XMLSchema::string().toString(),
+                          Util::fieldUri( FieldRegister::mtimeFieldName ).toString(),
+                          Util::fieldUri( FieldRegister::pathFieldName ).toString(),
+                          Node( QUrl::fromLocalFile( QFile::decodeName( parent.c_str() ) ) ).toN3() );
 
-    qDebug() << "running getChildren query:" << query;
+//    qDebug() << "running getChildren query:" << query;
 
-    QueryResultIterator result = d->repository->executeQuery( query, ::Soprano::Query::QUERY_LANGUAGE_SPARQL );
+    QueryResultIterator result = d->repository->executeQuery( query, ::Soprano::Query::QueryLanguageSparql );
 
     while ( result.next() ) {
         Node pathNode = result.binding( "path" );
         Node mTimeNode = result.binding( "mtime" );
 //        qDebug() << "file in index: " << pathNode.toString() << "mtime:" << mTimeNode.literal().toDateTime() << "(" << mTimeNode.literal().toDateTime().toTime_t() << ")";
 
-        // FIXME: Sadly in Xesam sourceModified is not typed as DateTime but defaults to an int :( We try to be compatible
+        // be backwards compatible in case there are paths left encoded as literals
+        std::string path;
+        if ( pathNode.isLiteral() )
+            path = pathNode.toString().toUtf8().data();
+        else
+            path = QFile::encodeName( pathNode.uri().toLocalFile() ).data();
+
+        // Sadly in Xesam sourceModified is not typed as DateTime but defaults to an int :( We try to be compatible
         if ( mTimeNode.literal().isDateTime() ) {
-            children[std::string( pathNode.toString().toUtf8().data() )] = mTimeNode.literal().toDateTime().toTime_t();
+            children[path] = mTimeNode.literal().toDateTime().toTime_t();
         }
         else {
-            children[std::string( pathNode.toString().toUtf8().data() )] = mTimeNode.literal().toUnsignedInt();
+            children[path] = mTimeNode.literal().toUnsignedInt();
         }
     }
 }
@@ -427,14 +451,14 @@ time_t Strigi::Soprano::IndexReader::mTime( const std::string& uri )
 {
 //    qDebug() << "IndexReader::mTime in thread" << QThread::currentThread();
     QString query = QString( "select ?mtime where { ?r <%2> \"%3\"^^<%4> . ?r <%1> ?mtime . }" )
-                    .arg( Util::fieldUri( FieldRegister::mtimeFieldName ).toString() )
-                    .arg( Util::fieldUri( FieldRegister::pathFieldName ).toString() )
-                    .arg( escapeLiteralForSparqlQuery( QString::fromUtf8( uri.c_str() ) ) )
-                    .arg( Vocabulary::XMLSchema::string().toString() );
+                    .arg( Util::fieldUri( FieldRegister::mtimeFieldName ).toString(),
+                          Util::fieldUri( FieldRegister::pathFieldName ).toString(),
+                          escapeLiteralForSparqlQuery( QString::fromUtf8( uri.c_str() ) ),
+                          Vocabulary::XMLSchema::string().toString() );
 
     qDebug() << "mTime( " << uri.c_str() << ") query:" << query;
 
-    QueryResultIterator it = d->repository->executeQuery( query, ::Soprano::Query::QUERY_LANGUAGE_SPARQL );
+    QueryResultIterator it = d->repository->executeQuery( query, ::Soprano::Query::QueryLanguageSparql );
 
     time_t mtime = 0;
     if ( it.next() ) {
@@ -459,7 +483,7 @@ std::vector<std::string> Strigi::Soprano::IndexReader::fieldNames()
     // Our list of field names (the predicates) is probably awefully long.
 
     std::vector<std::string> fields;
-    QueryResultIterator it = d->repository->executeQuery( "select distinct ?p where { ?r ?p ?o . }", ::Soprano::Query::QUERY_LANGUAGE_SPARQL );
+    QueryResultIterator it = d->repository->executeQuery( "select distinct ?p where { ?r ?p ?o . }", ::Soprano::Query::QueryLanguageSparql );
     while ( it.next() ) {
         fields.push_back( Util::fieldName( it.binding("p").uri() ) );
     }
